import { defineComponent, inject, watch, toRaw, onUnmounted, } from 'vue';
import useCleanUp from '../composables/use-clean-up';
const getLatLng = (latlngData) => {
    return new TMap.LatLng(latlngData.lat, latlngData.lng);
};
export default defineComponent({
    name: 'tmap-info-window',
    props: {
        id: {
            type: String,
            default: 'default',
        },
        visible: {
            type: Boolean,
            required: true,
        },
        position: {
            type: Object,
            required: true,
        },
        content: {
            type: String,
            required: true,
        },
        zIndex: {
            type: Number,
            required: false,
            default: 0,
        },
        offset: {
            type: Object,
            required: false,
            default: () => ({ x: 0, y: 0 }),
        },
    },
    emits: ['close-click'],
    setup(props, { emit }) {
        const map = inject('map');
        if (!map) {
            return {};
        }
        const originMap = toRaw(map.value);
        useCleanUp(originMap, props.id);
        const center = getLatLng(props.position);
        // 初始化infoWindow
        const infoWindow = new TMap.InfoWindow({
            map: toRaw(map.value),
            position: center,
            content: props.content,
            zIndex: props.zIndex,
            offset: props.offset,
        });
        infoWindow.on('closeclick', () => {
            emit('close-click');
        });
        watch(() => props.visible, (v) => {
            if (v) {
                infoWindow.open();
            }
            else {
                infoWindow.close();
            }
        });
        watch(() => props.content, (v) => {
            infoWindow.setContent(v);
        });
        watch(() => props.position, (v) => {
            infoWindow.setPosition(getLatLng(v));
        });
        onUnmounted(() => {
            infoWindow.destroy();
        });
        return {};
    },
    render() {
        return null;
    },
});
//# sourceMappingURL=info-window.js.map