import { defineComponent, inject, watch, toRaw, onUnmounted, } from 'vue';
import useCleanUp from '../composables/use-clean-up';
function builtStyle(opt) {
    const styled = {};
    Object.keys(opt).forEach((k) => {
        styled[k] = new TMap.LabelStyle(opt[k]);
    });
    return styled;
}
export default defineComponent({
    name: 'tmap-multi-label',
    props: {
        id: {
            type: String,
            default: 'default',
        },
        styles: {
            type: Object,
            required: true,
        },
        geometries: {
            type: Array,
            required: true,
        },
        enableCollision: {
            type: Boolean,
            required: false,
            default: false,
        },
    },
    setup(props) {
        const map = inject('map');
        if (!map) {
            return {};
        }
        const originMap = toRaw(map.value);
        useCleanUp(originMap, props.id);
        const getResGeo = (geo) => geo.map((item) => ({
            ...item,
            position: new TMap.LatLng(item.position.lat, item.position.lng),
        }));
        const labelInstance = new TMap.MultiLabel({
            id: props.id,
            map: toRaw(map.value),
            styles: builtStyle(props.styles),
            geometries: getResGeo(props.geometries),
            enableCollision: props.enableCollision,
        });
        watch(() => props.styles, (styles) => {
            labelInstance.setStyles(builtStyle(styles));
        });
        watch(() => props.geometries, (r) => {
            labelInstance.setGeometries(getResGeo(r));
        });
        onUnmounted(() => {
            labelInstance.setMap(null);
        });
        return {};
    },
    render() {
        return null;
    },
});
//# sourceMappingURL=multi-label.js.map